@@ -26,7 +26,6 @@
 #include <string.h>
 #include <glib.h>
 #include <glib/gi18n.h>
-#include <glib/gurifuncs.h>
 #include <gio/gio.h>
 
 #include <avahi-client/client.h>
@@ -74,12 +73,6 @@ static struct {
           FALSE,
           "folder-remote-ssh"
         },
-	{
-          "_ssh._tcp",
-          "sftp",
-          FALSE,
-          "folder-remote-ssh"
-        },
 	{
 	  "_smb._tcp",
 	  "smb",
